% Problem 2.11
%{
MATLAB R2015b
Calculate rotated 2D compliance matrix S and stiffness matrix Q 
from the engineering properties EL,ET,GLT,G23,nuLT
for a range of angles theta
%}
%% initialization
clc         % clear command window 
clear       % clear workspace
close all   % close all figures
format compact  % eliminate the empty lines in the command window
%% input engineering properties
EL=140.0e9;   % longitudinal modulus, GPa
ET=10.05e9;    % transverse modulus, GPa
GLT=5.70e9;  % in-plane shear modulus, GPa
G23=3.40e9;  % transversely isotropic shear modulus, GPa
nuLT=0.313; % in-plane Poisson ratio
%% calculate derived property nu23
nu23=ET/(2*G23)-1;
%% calculate 2D compliance matrix S0 in material axes 
S0=[ 1/EL       -nuLT/EL  0       ;
   -nuLT/EL        1/ET     0       ;
    0              0       1/GLT    ]
%% define angle range in degree
theta=[0 30 45 60 90]; Ntheta=size(theta,2); T=zeros(3,3,Ntheta); Ttrans=T;
S=T; Q=T;
%% calculate rotation matrices and their transposed
for n=1:Ntheta
c=cosd(theta(n)); s=sind(theta(n)); % cos and sin with theta in degree
T(:,:,n)=   [c^2    s^2      2*s*c  ;
             s^2    c^2     -2*s*c  ;
             -s*c   s*c      c^2-s^2];
Ttrans(:,:,n)=T(:,:,n)'; % transposed of all the rotation matrices
end
%% (a) calculate rotated 2D compliance matrix S
for n=1:Ntheta
S(:,:,n)=Ttrans(:,:,n)*S0*T(:,:,n);
display(S(:,:,n),['S(' num2str(theta(n)) ' deg)'])
end
%% (b) calculate rotated 2D stiffness matrix Q
for n=1:Ntheta
Q(:,:,n)=S(:,:,n)\eye(3); % use mldivide  to get the inverse of S_2D
display(Q(:,:,n),['Q(' num2str(theta(n)) ' deg)'])
end
%% (c) calculate rotated 2D stiffness matrix from Q0 and T
Q0=S0\eye(3); % use mldivide  to get the inverse
maxQ0=max(max(Q0));
for n=1:Ntheta
    Tinv=T(:,:,n)\eye(3);
    Ttrans_inv=Ttrans(:,:,n)\eye(3);
QQ(:,:,n)=Tinv*Q0*Ttrans_inv;
display(QQ(:,:,n),['Q(' num2str(theta(n)) ' deg) via Eq. (2.146)'])
diff_Q=(QQ(:,:,n)-Q(:,:,n))/maxQ0;
display(diff_Q,...
    ['diff_Q(' num2str(theta(n)) ' deg) = (inv(S) - Q via Eq. (2.146))/maxQ0'])
end

