% Problem 2.12
%{
MATLAB R2015b
Calculate 2D compliance matrix S and stiffness matrix Q 
from the engineering properties EL,ET,GLT,G23,nuLT
for a dense range of angles theta 
plot elements Q(1,1), Q(2,2), Q(3,3), Q(1,3), Q(1,3) 
                                of the rotated stiffness matrix Q
%}
%% initialization
clc         % clear command window 
clear       % clear workspace
% close all   % close all figures
format compact  % eliminate the empty lines in the command window
GPa=1e9;
%% input engineering properties
EL=140.0e9;   % longitudinal modulus, GPa
ET=10.05e9;    % transverse modulus, GPa
GLT=5.70e9;  % in-plane shear modulus, GPa
G23=3.40e9;  % transversely isotropic shear modulus, GPa
nuLT=0.313; % in-plane Poisson ratio
%% calculate derived property nu23
nu23=ET/(2*G23)-1;
%% calculate 2D compliance matrix S0 in material axes 
S0=[ 1/EL       -nuLT/EL  0       ;
   -nuLT/EL        1/ET     0       ;
    0              0       1/GLT    ]
%% define angle range in degree
theta=1:90; Ntheta=size(theta,2); T=zeros(3,3,Ntheta); Ttrans=T;
S=T; Q=T;
%% calculate rotation matrices and their transposed
for n=1:Ntheta
c=cosd(theta(n)); s=sind(theta(n)); % cos and sin with theta in degree
T(:,:,n)=   [c^2    s^2      2*s*c  ;
             s^2    c^2     -2*s*c  ;
             -s*c   s*c      c^2-s^2];
Ttrans(:,:,n)=T(:,:,n)'; % transposed of all the rotation matrices
end
%% calculate rotated 2D compliance matrix S
for n=1:Ntheta
S(:,:,n)=Ttrans(:,:,n)*S0*T(:,:,n);
% display(S(:,:,n),['S(' num2str(theta(n)) ' deg)'])
end
%% calculate rotated 2D stiffness matrix Q
for n=1:Ntheta
Q(:,:,n)=S(:,:,n)\eye(3); % use mldivide  to get the inverse of S_2D
% display(Q(:,:,n),['Q(' num2str(theta(n)) ' deg)'])
end
%% plot the elements Q(1,1), Q(2,2), Q(3,3), Q(1,3) of the rotated Q
%% plot results
Q11(:)=Q(1,1,:); Q22(:)=Q(2,2,:); Q33(:)=Q(3,3,:); 
Q13(:)=Q(1,3,:); Q23(:)=Q(2,3,:);
figure (1)
% subplot(1,2,1); 
subplot(1,3,1); 
plot(theta,Q11/GPa,theta,Q22/GPa); xlim([0 90]); xlabel('\theta^o');
    ylabel('Q(1,1), Q(2,2), GPa');legend('Q11','Q22'); title('CFRP  T300-914');
% subplot(1,2,2); 
subplot(1,3,2); 
plot(theta,Q33/GPa); xlim([0 90]); xlabel('\theta^o');
    ylabel('Q(3,3), GPa'); title('CFRP  T300-914');
% figure (2)
subplot(1,3,3); 
plot(theta,Q13/GPa,theta,Q23/GPa); xlim([0 90]); xlabel('\theta^o');
    ylabel('Q(1,3), Q(2,3), GPa');legend('Q13','Q23'); title('CFRP  T300-914');




















