% Problem 2.13
%{
MATLAB R2015b
Calculate rotated 3D compliance matrix S and stiffness matrix C 
from the engineering properties EL,ET,GLT,G23,nuLT
for a range of angles theta
%}
%% initialization
clc         % clear command window 
clear       % clear workspace
close all   % close all figures
format compact  % eliminate the empty lines in the command window
%% input engineering properties
EL=140.0e9;   % longitudinal modulus, GPa
ET=10.05e9;    % transverse modulus, GPa
GLT=5.70e9;  % in-plane shear modulus, GPa
G23=3.40e9;  % transversely isotropic shear modulus, GPa
nuLT=0.313; % in-plane Poisson ratio
%% calculate derived property nu23
nu23=ET/(2*G23)-1;
%% (a) calculate 3D compliance matrix in material axes S0
S0=[ 1/EL       -nuLT/EL    -nuLT/EL     0       0       0       ;
   -nuLT/EL     1/ET       -nu23/ET     0       0       0       ;
   -nuLT/EL    -nu23/ET     1/ET        0       0       0       ;
    0           0           0           1/G23   0       0       ;
    0           0           0           0       1/GLT   0       ;
    0           0           0           0       0       1/GLT   ]
%% define angle range in degree
theta=[0 30 45 60 90]; Ntheta=size(theta,2); T=zeros(6,6,Ntheta); Ttrans=T;
S=T; Q=T; CC=T;
%% calculate rotation matrices and their transposed
for n=1:Ntheta
c=cosd(theta(n)); s=sind(theta(n)); % cos and sin with theta in degree
T(:,:,n)=   [c^2    s^2      0  0   0   2*s*c   ;
             s^2    c^2      0  0   0  -2*s*c   ;
             0      0        1  0   0   0       ;
             0      0        0  c   -s  0       ;
             0      0        0  s   c   0       ;
            -s*c    s*c      0  0   0   c^2-s^2];
Ttrans(:,:,n)=T(:,:,n)'; % transposed of all the rotation matrices
end
%% (a) calculate rotated 3D compliance matrix S
for n=1:Ntheta
S(:,:,n)=Ttrans(:,:,n)*S0*T(:,:,n);
display(S(:,:,n),['S(' num2str(theta(n)) ' deg)'])
end
%% (b) calculate rotated 3D stiffness matrix C from the rotated S
for n=1:Ntheta
C(:,:,n)=S(:,:,n)\eye(6); % use mldivide  to get the inverse of S
display(C(:,:,n),['C=inv(S)(' num2str(theta(n)) ' deg)'])
end
%% (c) calculate rotated 3D stiffness matrix from C0 and T
C0=S0\eye(6); % use mldivide  to get the inverse
maxC0=max(max(C0));
for n=1:Ntheta
    Tinv=T(:,:,n)\eye(6);
    Ttrans_inv=Ttrans(:,:,n)\eye(6);
CC(:,:,n)=Tinv*C0*Ttrans_inv;
display(CC(:,:,n),['C(' num2str(theta(n)) ' deg) via Eq. (2.193)'])
diff_C=(CC(:,:,n)-C(:,:,n))/maxC0;
display(diff_C,...
    ['diff_C(' num2str(theta(n)) ' deg) = (inv(S) - C via Eq. (2.193))/maxC0'])
end



















