% Problem 2.14
%{
MATLAB R2015b
Calculate 3D compliance matrix S and stiffness matrix Q 
from the engineering properties EL,ET,GLT,G23,nuLT
for a dense range of angles theta 
plot elements C(1,1), C(2,2), C(3,3), C(4,4), C(5,5), C(1,6), C(2,6)
                                        of the rotated stiffness matrix C
%}
%% initialization
clc         % clear command window 
clear       % clear workspace
% close all   % close all figures
format compact  % eliminate the empty lines in the command window
GPa=1e9;
%% input engineering properties
EL=140.0e9;   % longitudinal modulus, GPa
ET=10.05e9;    % transverse modulus, GPa
GLT=5.70e9;  % in-plane shear modulus, GPa
G23=3.40e9;  % transversely isotropic shear modulus, GPa
nuLT=0.313; % in-plane Poisson ratio
%% calculate derived property nu23
nu23=ET/(2*G23)-1;
%% calculate 3D compliance matrix S0 in material axes 
S0=[ 1/EL       -nuLT/EL    -nuLT/EL    0       0       0       ;
   -nuLT/EL     1/ET       -nu23/ET     0       0       0       ;
   -nuLT/EL    -nu23/ET     1/ET        0       0       0       ;
    0           0           0           1/G23   0       0       ;
    0           0           0           0       1/GLT   0       ;
    0           0           0           0       0       1/GLT   ]
%% define angle range in degree
theta=1:90; Ntheta=size(theta,2); T=zeros(6,6,Ntheta); Ttrans=T;
S=T; C=T;
%% calculate rotation matrices and their transposed
for n=1:Ntheta
c=cosd(theta(n)); s=sind(theta(n)); % cos and sin with theta in degree
T(:,:,n)=   [c^2    s^2      0  0   0   2*s*c   ;
             s^2    c^2      0  0   0  -2*s*c   ;
             0      0        1  0   0   0       ;
             0      0        0  c   -s  0       ;
             0      0        0  s   c   0       ;
            -s*c    s*c      0  0   0   c^2-s^2];
Ttrans(:,:,n)=T(:,:,n)'; % transposed of all the rotation matrices
end
%% calculate rotated 3D compliance matrix S
for n=1:Ntheta
S(:,:,n)=Ttrans(:,:,n)*S0*T(:,:,n);
% display(S(:,:,n),['S(' num2str(theta(n)) ' deg)'])
end
%% calculate rotated 3D stiffness matrix C
for n=1:Ntheta
C(:,:,n)=S(:,:,n)\eye(6); % use mldivide  to get the inverse of S
% display(C(:,:,n),['C(' num2str(theta(n)) ' deg)'])
end
%% plot the elements C(1,1), C(2,2), C(4,4), C(5,5), C(1,6), C(2,6) 
%                                                    of the rotated matrix C 
%% plot results
C11(:)=C(1,1,:); C22(:)=C(2,2,:); 
C44(:)=C(4,4,:); C55(:)=C(5,5,:); C66(:)=C(6,6,:); 
C16(:)=C(1,6,:); C26(:)=C(2,6,:);
figure (1)
% subplot(1,2,1); 
subplot(1,3,1); 
plot(theta,C11/GPa,theta,C22/GPa); xlim([0 90]); xlabel('\theta^o');
    ylabel('C(1,1), C(2,2), GPa');legend('C11','C22'); title('CFRP  T300-914');
% subplot(1,2,2); 
subplot(1,3,2); 
plot(theta,C44/GPa,theta,C55/GPa,theta,C66/GPa); xlim([0 90]); 
    xlabel('\theta^o'); ylabel('C(4,4), C(5,5), C(6,6), GPa'); 
    legend('C44','C55','C66'); title('CFRP  T300-914');
% figure (2)
subplot(1,3,3); 
plot(theta,C16/GPa,theta,C26/GPa); xlim([0 90]); xlabel('\theta^o');
    ylabel('C(1,6), C(2,6), GPa');legend('C16','C26'); title('CFRP  T300-914');




















