% Problem 2.5
%{
MATLAB R2015b
calculate CFRP composite properties from constituent properties
%}
%% initialization
clc         % clear command window 
clear       % clear workspace
close all   % close all figures
format compact  % eliminates empty lines in the command window
GPa=1e9; % scale factor for elastic modulus
%% input constituent properties and volume fraction
Ef=231e9;           % T300 carbon fiber modulus, GPa
nu_f=0.2;           % T300 carbon fiber Poisson ratio
rho_f=1.76e3;       % T300 carbon fiber density, kg/m^3
Em=3.9e9;          % 914 epoxy resin matrix modulus, GPa
nu_m=0.41;          % 914 epoxy resin matrix Poisson ratio                
rho_m=1.29e3;       % 914 epoxy resin matrix density, kg/m^3
vf=60e-2;           % fiber volume fraction
vm=1-vf;            % matrix volume fraction (assume no voids)
%% calculate derived constituent properties
Gf=Ef/(2*(1+nu_f)); % fiber shear modulus
Gm=Em/(2*(1+nu_m)); % matrix shear modulus
%% calculate properties
EL=Ef*vf+Em*vm;             % longitudinal modulus
ET=1/(1/Ef*vf+1/Em*vm);     % longitudinal modulus
nu_LT=nu_f*vf+nu_m*vm;      % in-plane Poisson ratio
GLT=1/(1/Gf*vf+1/Gm*vm);    % in-plane shear modulus
GLT_CAM=Gm*(1+vf+(1-vf)*Gm/Gf)/(1-vf+(1+vf)*Gm/Gf); % CAM GLT
eta23=(3-4*nu_m+Gm/Gf)/(4*(1-nu_m));    % coefficient for G23 calculation
G23=Gm*(vf+eta23*vm)/(eta23*vm+vf*Gm/Gf);  % transverse shear modulus
rho=rho_f*vf+rho_m*vm;      % density
%% display results
display ('T300 carbon fiber 914 epoxy CFRP results')
display([vf vm],'volume fraction: vf, vm');
display([Ef Em EL ET]/GPa,'Modulus, GPa: Ef, Em, EL, ET')
display([Gf Gm GLT GLT_CAM G23]/GPa,...
    'Shear modulus, GPa: Gf, Gm, GLT, GLT_CAM, G23,')
display([nu_f nu_m nu_LT],'Poisson ratio: nu_f, nu_m, nu_LT');
display([rho_f rho_m rho],'density, kg/m^3: rho_f, rho_m, rho');
                
                
                