% Problem 2.7
%{
MATLAB R2015b
estimate volume fraction of CFRP composite properties from stiffness matrix
and density
%}
%% initialization
clc         % clear command window 
clear       % clear workspace
close all   % close all figures
format compact  % eliminates empty lines in the command window
GPa=1e9; % scale factor for elastic modulus
%% input constituent properties and volume fraction
Ef=231e9;           % T300 carbon fiber modulus, GPa
nu_f=0.2;           % T300 carbon fiber Poisson ratio
rho_f=1.76e3;       % T300 carbon fiber density, kg/m^3
Em=3.9e9;          % 914 epoxy resin matrix modulus, GPa
nu_m=0.41;          % 914 epoxy resin matrix Poisson ratio                
rho_m=1.29e3;       % 914 epoxy resin matrix density, kg/m^3
%% calculate derived constituent properties
Gf=Ef/(2*(1+nu_f)); % fiber shear modulus
Gm=Em/(2*(1+nu_m)); % matrix shear modulus
%% T300-914 composite properties
rho=1560;            % composite density, kg/m^3
% input T300-914 CFRP composite stiffness matrix, GPa
C=  [143.8      6.2     6.2     0       0       0;
       6.2     13.3     6.5     0       0       0;
       6.2      6.5    13.3     0       0       0;
       0        0       0       3.4    0       0;
       0        0       0       0       5.7     0;
       0        0       0       0       0       5.7]*1.0e09;
% calculate the compliance matrix S by inversion of stiffness matrix C
S=C\eye(6); % use mldivide  to get the inverse of C
display(S,'compliance matrix S, 1/Pa');
% recover the engineering properties EL, ET, GLT, G23, nuLT
EL=1/S(1,1);        % longitudinal modulus
ET=1/S(2,2);        % transverse modulus
G23=1/S(4,4);       % transverse shear modulus
GLT=C(5,5);       % in-plane shear modulus
nuLT=-S(1,2)*EL;    % in-plane Poisson ratio
display([EL,ET,GLT G23]/GPa,'Moduli, GPa: EL, ET, GLT, G23')
display([nuLT],'nuLT')
%% calculate volume fraction from density
vf_density=(rho-rho_m)/(rho_f-rho_m)  % volume fraction estimated from density
%% calculate volume fraction from EL modulus
vf_EL=(EL-Em)/(Ef-Em)  % volume fraction estimated from EL
%% calculate volume fraction from ET modulus
vf_ET=(1/ET-1/Em)/(1/Ef-1/Em)  % volume fraction estimated from ET
%% calculate volume fraction from GLT modulus
vf_GLT=(1/GLT-1/Gm)/(1/Gf-1/Gm)  % volume fraction estimated from ET
%% calculate volume fraction from GLT_CAM modulus
vf_GLT_CAM=(Gf+Gm)/(Gf-Gm)*(GLT-Gm)/(GLT+Gm)...
                                % volume fraction estimated from ET
%% calculate volume fraction from G23 modulus
eta23=(3-4*nu_m+Gm/Gf)/(4*(1-nu_m));    % coefficient for G23 calculation
% vf_G23_1=eta23/(1/(1-Gm/G23)-(1-eta23)/(1-Gm/Gf))/(1-Gm/Gf)...
%                                 % volume fraction estimated from G23
% vf_G23_2=eta23*(G23/Gm-1)/(G23/Gm*eta23-G23/Gf+1-eta23)...
%                                 % volume fraction estimated from G23
vf_G23=(1+(1-G23/Gf)/eta23/(G23/Gm-1))^-1 ...
                                % volume fraction estimated from G23
%% calculate volume fraction from nuLT Poisson ratio
vf_nuLT=(nuLT-nu_m)/(nu_f-nu_m)  % volume fraction estimated from nuLT

vf_mean=...
    mean([vf_density vf_EL vf_ET  vf_GLT_CAM ]) 
vf_std=std([vf_density vf_EL vf_ET  vf_GLT_CAM ])
vf_std_rel=vf_std/vf_mean; display(vf_std_rel*100,'vf_std%')


%% display results
                
                
                