% Problem 2.8
%{
MATLAB R2015b
calculate and plot  composite properties from constituent properties for 
CFRP and GFRP
%}
%% initialization
clc         % clear command window 
clear       % clear workspace
% close all   % close all figures
GPa=1e9;
%% generate fiber volume fraction vf and matrix volume fraction vm
vf_max=0.8; Nvf=50; dvf=vf_max/Nvf; vf=zeros(Nvf+1,1); 
for n=1:Nvf+1; vf(n)=(n-1)*dvf; end
vm=1-vf;            % matrix volume fraction (assume no voids)
%% CFRP segment: input constituent properties and volume fraction
Ef=231e9;           % T300 carbon fiber modulus, GPa
nu_f=0.2;           % T300 carbon fiber Poisson ratio
rho_f=1.76e3;       % T300 carbon fiber density, kg/m^3
Em=3.9e9;          % 914 epoxy resin matrix modulus, GPa
nu_m=0.41;          % 914 epoxy resin matrix Poisson ratio                
rho_m=1.29e3;       % 914 epoxy resin matrix density, kg/m^3
%% calculate derived constituent properties
Gf=Ef/(2*(1+nu_f)); % fiber shear modulus
Gm=Em/(2*(1+nu_m)); % matrix shear modulus
%% calculate properties
z=zeros(Nvf+1,1); EL=z; ET=z; nu_LT=z; GLT=z; GLT_CAM=z; G23=z; rho=z;
for n=1:Nvf+1
EL(n)=Ef*vf(n)+Em*vm(n);             % longitudinal modulus
ET(n)=1/(1/Ef*vf(n)+1/Em*vm(n));     % transverse modulus
nu_LT(n)=nu_f*vf(n)+nu_m*vm(n);      % in-plane Poisson ratio
GLT(n)=1/(1/Gf*vf(n)+1/Gm*vm(n));    % in-plane shear modulus
GLT_CAM(n)=Gm*(1+vf(n)+(1-vf(n))*Gm/Gf)/(1-vf(n)+(1+vf(n))*Gm/Gf); % CAM GLT
eta23=(3-4*nu_m+Gm/Gf)/(4*(1-nu_m));    % coefficient for G23 calculation
G23(n)=Gm*(vf(n)+eta23*vm(n))/(eta23*vm(n)+vf(n)*Gm/Gf);  % transverse shear modulus
rho(n)=rho_f*vf(n)+rho_m*vm(n);      % density
end
%% display results
% display ('S-glass 917 epoxy GFRP results')
% display([vf vm],'volume fraction: vf, vm');
% display([Ef Em EL ET],'Modulus, GPa: Ef, Em, EL, ET')
% display([Gf Gm GLT GLT_CAM G23],...
%     'Shear modulus, GPa: Gf, Gm, GLT, GLT_CAM, G23,')
% display([nu_f nu_m nu_LT],'Poisson ratio: nu_f, nu_m, nu_LT');
% display([rho_f rho_m rho],'density, kg/m^3: rho_f, rho_m, rho');
%% plot results
figure(1)
subplot(1,2,1); 
plot(vf,EL/GPa); xlabel('vf'); ylabel('E_L, GPa');title('CFRP   E_L')
subplot(1,2,2); 
plot(vf,ET/GPa); xlabel('vf'); ylabel('E_T, GPa'); title('CFRP   E_T')
figure(2)
subplot(1,2,1);
plot(vf,GLT/GPa,vf,GLT_CAM/GPa); xlabel('vf'); ylabel('G_L_T, G_L_TCAM, GPa');...
    legend ('G_L_T', 'G_L_TCAM'); title('CFRP   G_L_T')
subplot(1,2,2); 
plot(vf,G23/GPa); xlabel('vf'); ylabel('G_2_3, GPa'); title('CFRP   G_2_3')
figure(3)
subplot(1,2,1); 
plot(vf,nu_LT); xlabel('vf'); ylabel('\nu_L_T'); title('CFRP   \nu_L_T')
subplot(1,2,2); 
plot(vf,rho); xlabel('vf'); ylabel('\rho, kg/m^3'); title('CFRP   \rho')

%% GFRP segment: input constituent properties and volume fraction
Ef=86.9e9;           % S-glass fiber modulus, GPa
nu_f=0.20;           % S-glass fiber Poisson ratio
rho_f=2.49e3;       % S-glass carbon fiber density, kg/m^3
Em=3.9e9;          % 914 epoxy resin matrix modulus, GPa
nu_m=0.41;          % 914 epoxy resin matrix Poisson ratio                
rho_m=1.29e3;       % 914 epoxy resin matrix density, kg/m^3
%% calculate derived constituent properties
Gf=Ef/(2*(1+nu_f)); % fiber shear modulus
Gm=Em/(2*(1+nu_m)); % matrix shear modulus
%% calculate properties
z=zeros(Nvf+1,1); EL=z; ET=z; nu_LT=z; GLT=z; GLT_CAM=z; G23=z; rho=z;
for n=1:Nvf+1
EL(n)=Ef*vf(n)+Em*vm(n);             % longitudinal modulus
ET(n)=1/(1/Ef*vf(n)+1/Em*vm(n));     % transverse modulus
nu_LT(n)=nu_f*vf(n)+nu_m*vm(n);      % in-plane Poisson ratio
GLT(n)=1/(1/Gf*vf(n)+1/Gm*vm(n));    % in-plane shear modulus
GLT_CAM(n)=Gm*(1+vf(n)+(1-vf(n))*Gm/Gf)/(1-vf(n)+(1+vf(n))*Gm/Gf); % CAM GLT
eta23=(3-4*nu_m+Gm/Gf)/(4*(1-nu_m));    % coefficient for G23 calculation
G23(n)=Gm*(vf(n)+eta23*vm(n))/(eta23*vm(n)+vf(n)*Gm/Gf);  % transverse shear modulus
rho(n)=rho_f*vf(n)+rho_m*vm(n);      % density
end
%% plot results
figure(4)
subplot(1,2,1); 
plot(vf,EL/GPa); xlabel('vf'); ylabel('E_L, GPa');title('GFRP   E_L')
subplot(1,2,2); 
plot(vf,ET/GPa); xlabel('vf'); ylabel('E_T, GPa'); title('GFRP   E_T')
figure(5)
subplot(1,2,1);
plot(vf,GLT/GPa,vf,GLT_CAM/GPa); xlabel('vf'); ylabel('G_L_T, G_L_TCAM, GPa');...
    legend ('G_L_T', 'G_L_TCAM'); title('GFRP   G_L_T')
subplot(1,2,2); 
plot(vf,G23/GPa); xlabel('vf'); ylabel('G_2_3, GPa'); title('GFRP   G_2_3')
figure(6)
subplot(1,2,1); 
plot(vf,nu_LT); xlabel('vf'); ylabel('\nu_L_T'); title('GFRP   \nu_L_T')
subplot(1,2,2); 
plot(vf,rho); xlabel('vf'); ylabel('\rho, kg/m^3'); title('GFRP   \rho')

                
                
                