% Problem 2.9
%{
MATLAB R2015b
calculate and plot composite properties calculated from constituent properties
using Eqs. (2.114)--(2.117) for CFRP and GFRP
%}
%% initialization
clc         % clear command window 
clear       % clear workspace
% close all   % close all figures
GPa=1e9;
%% generate fiber volume fraction vf and matrix volume fraction vm
vf_max=0.8; Nvf=50; dvf=vf_max/Nvf; vf=zeros(Nvf+1,1); 
for n=1:Nvf+1; vf(n)=(n-1)*dvf; end
vm=1-vf;            % matrix volume fraction (assume no voids)
%% CFRP segment: input constituent properties and volume fraction
Ef=231e9;           % T300 carbon fiber modulus, GPa
nu_f=0.2;           % T300 carbon fiber Poisson ratio
rho_f=1.76e3;       % T300 carbon fiber density, kg/m^3
Em=3.9e9;          % 914 epoxy resin matrix modulus, GPa
nu_m=0.41;          % 914 epoxy resin matrix Poisson ratio                
rho_m=1.29e3;       % 914 epoxy resin matrix density, kg/m^3
%% calculate derived constituent properties
Gf=Ef/(2*(1+nu_f)); % fiber shear modulus
Gm=Em/(2*(1+nu_m)); % matrix shear modulus
%% calculate properties
z=zeros(Nvf+1,1); 
EL=z; ELa=z; ET=z; ETa=z; GLT=z; GLTa=z; GLT_CAM=z; GLT_CAMa=z; 
for n=1:Nvf+1
EL(n)=Ef*vf(n)+Em*vm(n);             % longitudinal modulus, Eq. (2.80)
ELa(n)=Ef*vf(n);                     % approx. longitudinal modulus, Eq. (2.114)
ET(n)=1/(1/Ef*vf(n)+1/Em*vm(n));     % transverse modulus, Eq. (2.91)
ETa(n)=Em/vm(n);                     % approx. transverse modulus, Eq. (2.115)
GLT(n)=1/(1/Gf*vf(n)+1/Gm*vm(n));    % in-plane shear modulus, Eq. (2.109)
GLTa(n)=Gm/vm(n);                    % approx. in-plane shear mod., Eq. (2.116)
GLT_CAM(n)=Gm*(1+vf(n)+(1-vf(n))*Gm/Gf)/(1-vf(n)+(1+vf(n))*Gm/Gf);
    % CAM GLT, Eq. (2.111)
GLT_CAMa(n)=Gm*(1+vf(n))/(1-vf(n));    % approx. CAM GLT, Eq. (2.117)
end
%% display results
% display ('S-glass 917 epoxy GFRP results')
% display([vf vm],'volume fraction: vf, vm');
% display([Ef Em EL ET],'Modulus, GPa: Ef, Em, EL, ET')
% display([Gf Gm GLT GLT_CAM G23],...
%     'Shear modulus, GPa: Gf, Gm, GLT, GLT_CAM, G23,')
% display([nu_f nu_m nu_LT],'Poisson ratio: nu_f, nu_m, nu_LT');
% display([rho_f rho_m rho],'density, kg/m^3: rho_f, rho_m, rho');
%% plot results
figure(1)
subplot(1,2,1); 
plot(vf,EL/GPa,vf,ELa/GPa);xlabel('vf');ylabel('E_L, GPa');
    legend('EL','EL approx'); title('CFRP   E_L');
subplot(1,2,2); 
plot(vf,ET/GPa,vf,ETa/GPa); xlabel('vf'); ylabel('E_T, GPa'); 
    legend('ET','ET approx'); title('CFRP   E_T')
figure(2)
subplot(1,2,1);
plot(vf,GLT/GPa,vf,GLTa/GPa); xlabel('vf'); ylabel('G_L_T, GPa');
    legend ('G_L_T', 'G_L_T approx'); title('CFRP   G_L_T')
subplot(1,2,2); 
plot(vf,GLT_CAM/GPa,vf,GLT_CAMa/GPa); xlabel('vf'); ylabel('G_L_TCAM, GPa');
    legend ('G_L_TCAM', 'G_L_TCAM approx'); title('CFRP   G_L_TCAM')

%% GFRP segment: input constituent properties and volume fraction
Ef=86.9e9;           % S-glass fiber modulus, GPa
nu_f=0.20;           % S-glass fiber Poisson ratio
rho_f=2.49e3;       % S-glass carbon fiber density, kg/m^3
Em=3.9e9;          % 914 epoxy resin matrix modulus, GPa
nu_m=0.41;          % 914 epoxy resin matrix Poisson ratio                
rho_m=1.29e3;       % 914 epoxy resin matrix density, kg/m^3
%% calculate derived constituent properties
Gf=Ef/(2*(1+nu_f)); % fiber shear modulus
Gm=Em/(2*(1+nu_m)); % matrix shear modulus
%% calculate properties
z=zeros(Nvf+1,1); 
EL=z; ELa=z; ET=z; ETa=z; GLT=z; GLTa=z; GLT_CAM=z; GLT_CAMa=z; 
for n=1:Nvf+1
EL(n)=Ef*vf(n)+Em*vm(n);             % longitudinal modulus, Eq. (2.80)
ELa(n)=Ef*vf(n);                     % approx. longitudinal modulus, Eq. (2.114)
ET(n)=1/(1/Ef*vf(n)+1/Em*vm(n));     % transverse modulus, Eq. (2.91)
ETa(n)=Em/vm(n);                     % approx. transverse modulus, Eq. (2.115)
GLT(n)=1/(1/Gf*vf(n)+1/Gm*vm(n));    % in-plane shear modulus, Eq. (2.109)
GLTa(n)=Gm/vm(n);                    % approx. in-plane shear mod., Eq. (2.116)
GLT_CAM(n)=Gm*(1+vf(n)+(1-vf(n))*Gm/Gf)/(1-vf(n)+(1+vf(n))*Gm/Gf);
    % CAM GLT, Eq. (2.111)
GLT_CAMa(n)=Gm*(1+vf(n))/(1-vf(n));    % approx. CAM GLT, Eq. (2.117)
end
%% plot results
figure(3)
subplot(1,2,1); 
plot(vf,EL/GPa,vf,ELa/GPa);xlabel('vf');ylabel('E_L, GPa');legend('EL','EL approx');
    title('GFRP   E_T')
subplot(1,2,2); 
plot(vf,ET/GPa,vf,ETa/GPa); xlabel('vf'); ylabel('E_T, GPa'); 
legend('ET','ET approx'); title('GFRP   E_T')
figure(4)
subplot(1,2,1);
plot(vf,GLT/GPa,vf,GLTa/GPa); xlabel('vf'); ylabel('G_L_T, GPa');
    legend ('G_L_T', 'G_L_T approx'); title('GFRP   G_L_T')
subplot(1,2,2); 
plot(vf,GLT_CAM/GPa,vf,GLT_CAMa/GPa); xlabel('vf'); ylabel('G_L_TCAM, GPa');
    legend ('G_L_TCAM', 'G_L_TCAM approx'); title('GFRP   G_2_3')

                
                
                